OC.L10N.register(
    "mail",
    {
    "Mail" : "البريد",
    "Loading accounts" : "تجهيز الحسابات",
    "Error while loading the accounts." : "حدث خطأ خلال تحميل الحسابات.",
    "Error while loading the selected account." : "حدث خطأ خلال تحميل الحساب المُختار.",
    "Can not load this folder." : "يتعذر تحميل هذا المجلد.",
    "Searching for {query}" : "بحث عن {query}",
    "Error while deleting message." : "حدث خطأ خلال حذف الرسالة.",
    "Forwarded message" : "تمرير الرسالة",
    "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
    "Attachments saved to Files." : "تم حفظ المرفقات لـ الملفات.",
    "Attachment saved to Files." : "تم حفظ المرفق لـ الملفات.",
    "Error while saving attachments to Files." : "حدث خطأ خلال حفظ المرفقات لـ الملفات.",
    "Error while saving attachment to Files." : "حدث خطأ خلال حفظ المرفق لـ الملفات.",
    "Message flag could not be set." : "تعذر تعيين إشارة للرسالة.",
    "Could not move message." : "تعذر نقل الرسالة.",
    "Invalid account" : "حساب غير صالح",
    "Invalid folder" : "مجلد غير صالح",
    "Error while creating the account: " : "حدث خطأ عند إنشاء الحساب:",
    "Unknown error" : "حدث خطأ غير معروف. ",
    "Error while updating the account: " : "طرأ هناك خطأ أثناء تحديث الحساب :",
    "All inboxes" : "جميع الوارد",
    "you" : "أنت",
    "Send message to {email}" : "أرسل رسالة لـ {email}",
    "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
    "Could not load the message" : "تعذرت عملية تحميل الرسالة",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "بريد ناكست كلاود",
    "Save" : "حفظ",
    "Saved" : "تم الإحتفاظ به",
    "Show all folders" : "أظهر جميع المجلدات",
    "Collapse folders" : "طي المجلدات",
    "Error while deleting account." : "حدث خطأ خلال عملية حذف الحساب.",
    "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
    "An error occurred while uploading {fname}" : "يحدث خلل عند رفع {fname}",
    "Reply" : "رد",
    "Send" : "أرسل",
    "Sending …" : "جار الإرسال",
    "Message sent!" : "تم الإرسال الرسالة!",
    "Server error" : "خطا في الخادم",
    "An unknown error occurred" : "حدث خلل غير معروف",
    "Opening HTML drafts is not supported yet." : "فتح مسودات HTML غير مدعّم حاليا.",
    "Error while importing the calendar event" : "خلل عند استيراد أحداث التقويم",
    "Error while downloading calendar event" : "خلل عند تحميل احداث التقويم",
    "& others" : "و آخرون",
    "Error while loading messages." : "حدث خطأ خلال تحميل الرسائل.",
    "Setting up your account" : "إعدادات حسابك",
    "Inbox" : "صندوق الوارد",
    "Sent" : "أرسلت",
    "Drafts" : "المسودات",
    "Archive" : "الأرشيف",
    "Trash" : "سلة المحذوفات",
    "Junk" : "عشوائي",
    "All" : "الكل",
    "Favorites" : "المفضلة ",
    "Auto detect failed. Please use manual mode." : "فشل في عملية التحقق الآلي. الرجاء استخدام نمط الدليل.",
    "Updating account failed: " : "فشلت عملية تحديث الحساب :",
    "Creating account failed: " : "فشل في إنشاء الحساب:",
    "Delete permanently" : "حذف بشكل دائم",
    "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
    "Settings" : "الإعدادات",
    "Forwarding to %s" : "تمرير إلى %s",
    "Click here if you are not automatically redirected within the next few seconds." : "إضغط هنا إذا لم يتم إعادة توجيهك تلقائياً بعد عدة ثواني.",
    "Redirect" : "إعادة توجيه",
    "The link leads to %s" : "الرابط يؤدي إل %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "إذا لم ترغب في زيارة الصفحة، بإمكانك العودة لـ <a href=\"%s\">البريد</a>",
    "Continue to %s" : "أكمل إلى %s",
    "Delete account" : "حذف الحساب",
    "Try again" : "عاود المحاولة",
    "New message" : "رسالة جديدة",
    "Account Settings" : "إعدادات الحساب",
    "Aliases" : "أسماء مسعارة",
    "Mail address" : "عنوان البريد الإلكتروني",
    "Display Name" : "إسم العرض",
    "Account" : "الحساب",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
    "Compose new message" : "إرسل رسالة جديدة",
    "Newer message" : "الرسائل الأحدث",
    "Older message" : "الرسائل الأقدم",
    "Toggle star" : "حدد النجوم",
    "Toggle unread" : "حدد الغير مقروء",
    "Delete" : "حذف",
    "Search" : "بحث",
    "Refresh" : "تحديث",
    "Connect your mail account" : "تحديث",
    "Name" : "الإسم",
    "Mail Address" : "عنوان البريد الإلكتروني",
    "Password" : "كلمة المرور",
    "Manual configuration" : "الإعدادات اليدوية",
    "IMAP Host" : "مُضيف IMAP",
    "IMAP security" : "حماية IMAP",
    "None" : "بلا",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "منفذ IMAP",
    "IMAP User" : "مستخدم IMAP",
    "IMAP Password" : "كلمة مرور IMAP",
    "SMTP Host" : "مُضيف SMTP",
    "SMTP security" : "حماية SMTP",
    "SMTP Port" : "منفذ SMTP",
    "SMTP User" : "مستخدم SMTP",
    "SMTP Password" : "كلمة مرور SMTP",
    "Connect" : "اتصال",
    "from" : "من",
    "to" : "إلى",
    "cc" : "نسخة كربونية",
    "bcc" : "نسخة كربونية سرية",
    "Subject" : "الموضوع",
    "Save all to Files" : "حفظ الجميع لـ الملفات",
    "Add mail account" : "أضف حساب بريدي",
    "No search results for" : "لا نتائج بحث لـ",
    "The images have been blocked to protect your privacy." : "تح حجب هذه الصورة لحماية خصوصيتك",
    "Show images from this sender" : "أظهر الصور من هذا المُرسل",
    "Forward" : "مرر",
    "No messages in this folder!" : "هذا المجلد خالٍ مِن الرسائل !",
    "Upload attachment" : "رفع المرفقات",
    "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
    "Import into calendar" : "إستيراد من التقويم",
    "Download attachment" : "تنزيل الملحق",
    "Save to Files" : "حفظ للـ الملفات"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
